# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.resources__admin_only_api import ResourcesAdminOnlyApi  # noqa: E501
from swagger_client.rest import ApiException


class TestResourcesAdminOnlyApi(unittest.TestCase):
    """ResourcesAdminOnlyApi unit test stubs"""

    def setUp(self):
        self.api = ResourcesAdminOnlyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_delete_resource(self):
        """Test case for cf_manager_rest_api_delete_resource

        Remove a resource  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_available_resources(self):
        """Test case for cf_manager_rest_api_get_available_resources

        Get all cloudFPGA resources in state `{status}`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_resources(self):
        """Test case for cf_manager_rest_api_get_resources

        Get all cloudFPGA resources  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_resources_of_sled_status(self):
        """Test case for cf_manager_rest_api_get_resources_of_sled_status

        Get status of **all resources** from a specific sled  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_resources_of_sled_status_in_state(self):
        """Test case for cf_manager_rest_api_get_resources_of_sled_status_in_state

        Get status of **all resources** from a specific sled in a specific `{status}`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_single_resource(self):
        """Test case for cf_manager_rest_api_get_single_resource

        Get details of one resource  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_single_resource_status(self):
        """Test case for cf_manager_rest_api_get_single_resource_status

        Get status of one resource  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_resources(self):
        """Test case for cf_manager_rest_api_post_resources

        Create a cloudFPGA resource  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_put_resource(self):
        """Test case for cf_manager_rest_api_put_resource

        Update a resource  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_put_resource_status(self):
        """Test case for cf_manager_rest_api_put_resource_status

        Update status of a resource  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_put_resources_of_sled_status(self):
        """Test case for cf_manager_rest_api_put_resources_of_sled_status

        Update status of **all resources** from a specific sled  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_put_resources_of_sled_status_in_state(self):
        """Test case for cf_manager_rest_api_put_resources_of_sled_status_in_state

        Update status of **all resources** from a specific sled in a specific `{status}`  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
