# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.instances_api import InstancesApi  # noqa: E501
from swagger_client.rest import ApiException


class TestInstancesApi(unittest.TestCase):
    """InstancesApi unit test stubs"""

    def setUp(self):
        self.api = InstancesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_app_restart_instance(self):
        """Test case for cf_manager_rest_api_app_restart_instance

        Triggers app restart of this instance  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_delete_instance(self):
        """Test case for cf_manager_rest_api_delete_instance

        Remove an instance  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_instance(self):
        """Test case for cf_manager_rest_api_get_instance

        Get a single instance  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_instances(self):
        """Test case for cf_manager_rest_api_get_instances

        Get all instances of a user  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_instance_api_gateway(self):
        """Test case for cf_manager_rest_api_instance_api_gateway

        Forwards a custom HTTP API request  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_instance_change_runlevel(self):
        """Test case for cf_manager_rest_api_instance_change_runlevel

        Changes the `runlevel` of the instance (stack developers only)  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_instance_get_runlevel(self):
        """Test case for cf_manager_rest_api_instance_get_runlevel

        Returns the current `runlevel` of the instance (stack developers only)  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_instances(self):
        """Test case for cf_manager_rest_api_post_instances

        Create an instance  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_update_instance(self):
        """Test case for cf_manager_rest_api_update_instance

        Reprogramm an instance  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
