# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.images_api import ImagesApi  # noqa: E501
from swagger_client.rest import ApiException


class TestImagesApi(unittest.TestCase):
    """ImagesApi unit test stubs"""

    def setUp(self):
        self.api = ImagesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_delete_image(self):
        """Test case for cf_manager_rest_api_delete_image

        Delete an image  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_image_single(self):
        """Test case for cf_manager_rest_api_get_image_single

        Get an image  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_images(self):
        """Test case for cf_manager_rest_api_get_images

        Get all images of a user  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_app_logic(self):
        """Test case for cf_manager_rest_api_post_app_logic

        Upload an image of type `app logic`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_images(self):
        """Test case for cf_manager_rest_api_post_images

        Upload an image  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
