# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.projects_api import ProjectsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self):
        self.api = ProjectsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_get_project_quota(self):
        """Test case for cf_manager_rest_api_get_project_quota

        Get the current quota of a project  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_list_projects(self):
        """Test case for cf_manager_rest_api_list_projects

        List the projects the user belongs to  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_project_quota(self):
        """Test case for cf_manager_rest_api_post_project_quota

        Post a new (or update existent) quota of a project (admin only)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
