# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.clusters_api import ClustersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestClustersApi(unittest.TestCase):
    """ClustersApi unit test stubs"""

    def setUp(self):
        self.api = ClustersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_delete_cluster(self):
        """Test case for cf_manager_rest_api_delete_cluster

        Delete a cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_extend_cluster(self):
        """Test case for cf_manager_rest_api_extend_cluster

        Add nodes to an existing cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_cluster_single(self):
        """Test case for cf_manager_rest_api_get_cluster_single

        Get a cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_clusters(self):
        """Test case for cf_manager_rest_api_get_clusters

        Get all clusters of a user  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_post_clusters(self):
        """Test case for cf_manager_rest_api_post_clusters

        Request a cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_reduce_cluster(self):
        """Test case for cf_manager_rest_api_reduce_cluster

        Remove nodes from an existing cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_restart_cluster(self):
        """Test case for cf_manager_rest_api_restart_cluster

        Restart all application on FPGAs in this cluster  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_update_node_of_cluster(self):
        """Test case for cf_manager_rest_api_update_node_of_cluster

        Reconfigure one FPGA node of an existing cluster  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
