# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.mantle_architecture_api import MantleArchitectureApi  # noqa: E501
from swagger_client.rest import ApiException


class TestMantleArchitectureApi(unittest.TestCase):
    """MantleArchitectureApi unit test stubs"""

    def setUp(self):
        self.api = MantleArchitectureApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_get_composable_logic_all_part(self):
        """Test case for cf_manager_rest_api_get_composable_logic_all_part

        Returns all composable logics of the given part that are `IN_USE`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_composable_logic_all_prp(self):
        """Test case for cf_manager_rest_api_get_composable_logic_all_prp

        Returns all composable logics of the given prp-type that are `IN_USE`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_composable_logic_all_shell_type(self):
        """Test case for cf_manager_rest_api_get_composable_logic_all_shell_type

        Returns all composable logics of the given shell-type that are `IN_USE`  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_composable_logic_dcp(self):
        """Test case for cf_manager_rest_api_get_composable_logic_dcp

        Get the dcp file of a composable logic  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_composable_logic_meta(self):
        """Test case for cf_manager_rest_api_get_composable_logic_meta

        Get the meta data of a composable logic  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
