# coding: utf-8

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.debug_api import DebugApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDebugApi(unittest.TestCase):
    """DebugApi unit test stubs"""

    def setUp(self):
        self.api = DebugApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cf_manager_rest_api_delete_debug_connection(self):
        """Test case for cf_manager_rest_api_delete_debug_connection

        Deletes an existing connection to the `hw_server` of this instance  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_all_debug_connections(self):
        """Test case for cf_manager_rest_api_get_all_debug_connections

        Requests a list of running `hw_server`s on all instances (admin only)  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_all_debug_connections_of_user(self):
        """Test case for cf_manager_rest_api_get_all_debug_connections_of_user

        Returns all open `hw_server` of a user  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_debug_connection(self):
        """Test case for cf_manager_rest_api_get_debug_connection

        Requests a connection to the `hw_server` of this instance  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_flight_recorder_cluster(self):
        """Test case for cf_manager_rest_api_get_flight_recorder_cluster

        Requests network runtime information of all instances  # noqa: E501
        """
        pass

    def test_cf_manager_rest_api_get_flight_recorder_instance(self):
        """Test case for cf_manager_rest_api_get_flight_recorder_instance

        Requests network runtime information  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
