# coding: utf-8

# flake8: noqa

"""
    cloudFPGA Resource Manager API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.8
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.administration__admin_only_api import AdministrationAdminOnlyApi
from swagger_client.api.clusters_api import ClustersApi
from swagger_client.api.debug_api import DebugApi
from swagger_client.api.images_api import ImagesApi
from swagger_client.api.instances_api import InstancesApi
from swagger_client.api.mantle_architecture_api import MantleArchitectureApi
from swagger_client.api.projects_api import ProjectsApi
from swagger_client.api.resources__admin_only_api import ResourcesAdminOnlyApi
# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.administration_mantle_logic_body import AdministrationMantleLogicBody
from swagger_client.models.administration_platform_logic_body import AdministrationPlatformLogicBody
from swagger_client.models.build_script import BuildScript
from swagger_client.models.cluster import Cluster
from swagger_client.models.cluster_id_node_id_body import ClusterIdNodeIdBody
from swagger_client.models.clusters_body import ClustersBody
from swagger_client.models.image import Image
from swagger_client.models.images_app_logic_body import ImagesAppLogicBody
from swagger_client.models.images_body import ImagesBody
from swagger_client.models.inline_response200 import InlineResponse200
from swagger_client.models.inline_response2001 import InlineResponse2001
from swagger_client.models.inline_response2002 import InlineResponse2002
from swagger_client.models.inline_response2003 import InlineResponse2003
from swagger_client.models.inline_response2004 import InlineResponse2004
from swagger_client.models.inline_response2005 import InlineResponse2005
from swagger_client.models.instance import Instance
from swagger_client.models.instance_id_api_gateway_body import InstanceIdApiGatewayBody
from swagger_client.models.instance_id_runlevel_body import InstanceIdRunlevelBody
from swagger_client.models.instances_body import InstancesBody
from swagger_client.models.instances_instance_id_body import InstancesInstanceIdBody
from swagger_client.models.node_map import NodeMap
from swagger_client.models.node_map_inner import NodeMapInner
from swagger_client.models.quota import Quota
from swagger_client.models.resource import Resource
from swagger_client.models.test_instance_instance_id_body import TestInstanceInstanceIdBody
